.. :changelog:

History
-------

0.2.1 (2016-11-25)
++++++++++++++++++

* Settings are taken from the environment variables by default

0.2.0 (2016-11-17)
++++++++++++++++++

* The root URL includes the `.well-known/acme-challenge/` prefix.
* Accept an optional `/` at the end of the URL
* Updated documentation

0.1.3 (2016-11-17)
++++++++++++++++++

* Bump version, various minor docs updates

0.1.0 (2016-11-16)
++++++++++++++++++

* First release on PyPI.
